@@ -7,6 +7,12 @@ class CustomViewOperations(object):
 
 
 	def get_custom_views(self):
+		"""
+		The method to get custom views
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/custom_views"
@@ -17,6 +23,15 @@ class CustomViewOperations(object):
 		return handler_instance.api_call(ResponseHandler.__module__, "application/json")
 
 	def get_custom_view(self, id):
+		"""
+		The method to get custom view
+
+		Parameters:
+			id (string) : A string value
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/custom_views/"
