@@ -7,6 +7,12 @@ class OrganizationOperations(object):
 
 
 	def get_organization(self):
+		"""
+		The method to get organization
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/org"
