@@ -7,6 +7,12 @@ class ProfileOperations(object):
 
 
 	def get_profiles(self):
+		"""
+		The method to get profiles
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/profiles"
@@ -16,6 +22,15 @@ class ProfileOperations(object):
 		return handler_instance.api_call(ResponseHandler.__module__, "application/json")
 
 	def get_profile(self, id):
+		"""
+		The method to get profile
+
+		Parameters:
+			id (string) : A string value
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/profiles/"
