@@ -6,7 +6,13 @@ class RelatedListOperations(object):
 		self.__module = module
 
 
-	def get_related_list(self):
+	def get_related_lists(self):
+		"""
+		The method to get related lists
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/related_lists"
@@ -17,6 +23,15 @@ class RelatedListOperations(object):
 		return handler_instance.api_call(ResponseHandler.__module__, "application/json")
 
 	def get_related_list(self, id):
+		"""
+		The method to get related list
+
+		Parameters:
+			id (string) : A string value
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/related_lists/"
