@@ -7,6 +7,12 @@ class RoleOperations(object):
 
 
 	def get_roles(self):
+		"""
+		The method to get roles
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/roles"
@@ -16,6 +22,15 @@ class RoleOperations(object):
 		return handler_instance.api_call(ResponseHandler.__module__, "application/json")
 
 	def get_role(self, id):
+		"""
+		The method to get role
+
+		Parameters:
+			id (string) : A string value
+
+		Returns:
+			APIResponse: An instance of APIResponse
+		"""
 		handler_instance = CommonAPIHandler()
 		api_path = ''
 		api_path = api_path + "/crm/v2/settings/roles/"
